@@ -85,10 +85,10 @@ class CreateNetworkInterfaceRequest(RpcRequest):
 	def set_InstanceType(self,InstanceType):
 		self.add_query_param('InstanceType',InstanceType)
 
-	def get_Tag(self):
+	def get_Tags(self):
 		return self.get_query_params().get('Tag')
 
-	def set_Tag(self, Tags):
+	def set_Tags(self, Tags):
 		for depth1 in range(len(Tags)):
 			if Tags[depth1].get('Key') is not None:
 				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
@@ -125,10 +125,10 @@ class CreateNetworkInterfaceRequest(RpcRequest):
 	def set_OwnerId(self,OwnerId):
 		self.add_query_param('OwnerId',OwnerId)
 
-	def get_SecurityGroupIds(self):
+	def get_SecurityGroupIdss(self):
 		return self.get_query_params().get('SecurityGroupIds')
 
-	def set_SecurityGroupIds(self, SecurityGroupIdss):
+	def set_SecurityGroupIdss(self, SecurityGroupIdss):
 		for depth1 in range(len(SecurityGroupIdss)):
 			if SecurityGroupIdss[depth1] is not None:
 				self.add_query_param('SecurityGroupIds.' + str(depth1 + 1) , SecurityGroupIdss[depth1])
@@ -139,10 +139,10 @@ class CreateNetworkInterfaceRequest(RpcRequest):
 	def set_VSwitchId(self,VSwitchId):
 		self.add_query_param('VSwitchId',VSwitchId)
 
-	def get_PrivateIpAddress(self):
+	def get_PrivateIpAddresss(self):
 		return self.get_query_params().get('PrivateIpAddress')
 
-	def set_PrivateIpAddress(self, PrivateIpAddresss):
+	def set_PrivateIpAddresss(self, PrivateIpAddresss):
 		for depth1 in range(len(PrivateIpAddresss)):
 			if PrivateIpAddresss[depth1] is not None:
 				self.add_query_param('PrivateIpAddress.' + str(depth1 + 1) , PrivateIpAddresss[depth1])
